# PyTeXMK
LaTeX 辅助编译程序

positional arguments:
| Option              | Description                                           |
|---------------------|-------------------------------------------------------|
| document          | 要被编译的文件名                      |

options:
| Option              | Description                                           |
|---------------------|-------------------------------------------------------|
| -h, --help          | Show this help message and exit                       |
| -v, --version       | Show program's version number and exit               |
| -c, --clean         | 清除所有辅助文件                                      |
| -C, --Clean         | 清除所有辅助文件和 pdf 文件                            |
| -nq, --no-quiet     | 非安静模式运行，此模式下显示编译过程                   |
| -p, --pdflatex      | pdflatex 进行编译                                    |
| -x, --xelatex       | xelatex 进行编译                                     |
| -l, --lualatex      | lualatex 进行编译                                    |
